@@ -2,9 +2,10 @@ import hashlib
 from dataclasses import dataclass
 from itertools import count
 from pathlib import Path
-from typing import Dict, Iterator, List, Mapping, Optional, Union
+from typing import Dict, Iterator, List, Optional, Union
 
 import requests
+from dacite import from_dict
 
 
 @dataclass(frozen=True)
@@ -21,16 +22,22 @@ class Channel:
 
 
 @dataclass(frozen=True)
-class ChannelMember:
-    username: str
-    role: str
+class Profile:
+    name: str
+    avatar_url: str
 
 
 @dataclass(frozen=True)
 class User:
     id: str
     username: str
-    profile: Mapping
+    profile: Profile
+
+
+@dataclass(frozen=True)
+class ChannelMember:
+    user: User
+    role: str
 
 
 @dataclass(frozen=True)
@@ -91,7 +98,7 @@ class QuetzClient:
         response = self.session.get(url=url)
         response.raise_for_status()
         for member_json in response.json():
-            yield ChannelMember(**member_json)
+            yield from_dict(ChannelMember, member_json)
 
     def yield_users(self, query: str = "", limit: int = 20) -> Iterator[User]:
         url = f"{self.url}/api/paginated/users"
